Recipes for common wired Ethernet configurations
Summary
Functions
Return a configuration for connecting to Ethernet network with a DHCP server
Recipes for common wired Ethernet configurations
Return a configuration for connecting to Ethernet network with a DHCP server