VintageNetEthernet.MacAddress (vintage_net_ethernet v0.11.1)

Copy Markdown View Source

MAC Address utilities

Summary

Types

t()

A MAC address is a string of the form "aa:bb:cc:dd:ee:ff"

Functions

Return true if this is a valid MAC address

Types

t()

@type t() :: <<_::136>>

A MAC address is a string of the form "aa:bb:cc:dd:ee:ff"

Functions

valid?(arg1)

@spec valid?(any()) :: boolean()

Return true if this is a valid MAC address