VintageNet.Technology.Ethernet (vintage_net_ethernet v0.10.3) View Source

Deprecated - Use VintageNetEthernet now

This module will automatically redirect your configurations to VintageNetEthernet so no changes are needed to your code. New code should use the new module.