VintageNet.Technology.Ethernet (vintage_net_ethernet v0.10.0) View Source
Deprecated - Use VintageNetEthernet now
This module will automatically redirect your configurations to VintageNetEthernet so no changes are needed to your code. New code should use the new module.
Link to this section Summary
Functions
Callback implementation for VintageNet.Technology.check_system/1.
Callback implementation for VintageNet.Technology.ioctl/3.
Link to this section Functions
Callback implementation for VintageNet.Technology.check_system/1.
Callback implementation for VintageNet.Technology.ioctl/3.