VintageNetEthernet.Cookbook (vintage_net_ethernet v0.11.0)

Copy Markdown View Source

Recipes for common wired Ethernet configurations

Summary

Functions

Return a configuration for connecting to Ethernet network with a DHCP server

Functions

dynamic_ipv4()

@spec dynamic_ipv4() :: {:ok, %{type: VintageNetEthernet, ipv4: %{method: :dhcp}}}

Return a configuration for connecting to Ethernet network with a DHCP server